@@ -4,11 +4,12 @@ import os
 import sys
 
 class ManimLive:
-    def __init__(self, directory, fullscreen=False):
+    def __init__(self, directory, fullscreen=False, dimensions=[800, 1280]):
         self.directory = directory
         self.fullscreen = fullscreen
         self.window = ''
         self.files = {}
+        self.anim_num = 0
         for i, filename in enumerate(os.listdir(self.directory)):
             if filename.endswith(".mp4"):
                 self.files[filename[:-4]] = {}
@@ -31,28 +32,32 @@ class ManimLive:
             self.files[f]['number'] = file_numbers[i]
 
     def play_anim(self):
+        self.anim_num = 0
+
         self.window = pyglet.window.Window(fullscreen=self.fullscreen)
         player = pyglet.media.Player()
 
-        for i in range(len(self.files)):
-            for f in self.files: 
-                if self.files[f]['number'] == i:
-                    MediaLoad = pyglet.media.load(os.path.join(self.directory, self.files[f]['name']))
-                    player.queue(MediaLoad)
+        for f in self.files: 
+            if self.files[f]['number'] == self.anim_num:
+                MediaLoad = pyglet.media.load(os.path.join(self.directory, self.files[f]['name']))
+                player.queue(MediaLoad)
 
         player.play()
 
+
         @self.window.event
         def on_draw():
             if player.source and player.source.video_format:
-                player.get_texture().blit(0,0)   
-
-        def on_eos():
-            player.pause()
+                player.get_texture().blit(0,0)
 
         @self.window.event
         def on_key_press(key, modifiers):
             if key == pyglet.window.key.N and not player.playing:
+                self.anim_num += 1
+                for f in self.files: 
+                    if self.files[f]['number'] == self.anim_num:
+                        MediaLoad = pyglet.media.load(os.path.join(self.directory, self.files[f]['name']))
+                        player.queue(MediaLoad)
                 player.play()
 
         player.push_handlers(on_eos) 
@@ -72,4 +77,11 @@ class ManimLive:
             
     def menu_el(self, x, y):
         return shapes.Rectangle(x + self.window.height*0.1/4, y + self.window.height*0.1/4, self.window.width/self.menu_el_cols - self.window.height*0.1/2, self.window.height/self.menu_el_rows - self.window.height*0.1/2, color=(55, 55, 255))
-            
\ No newline at end of file
+
+'''            
+live = ManimLive("./media/", True)
+
+live.play_anim()
+live.change_order([2,3,1])
+live.run()
+'''
\ No newline at end of file
